define(["require", "exports", "fs", "os", "path"], function (require, exports, fs, os, path) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    function setDatabasePaths(sqlitePath) {
        const databaseBasePath = getSqliteStoragePath(sqlitePath);
        const logsStoragePath = path.join(databaseBasePath, 'logs');
        process.env.process_engine__logging_repository__log_output_path = logsStoragePath;
        const correlationRepositoryConfig = readConfigFile(process.env.NODE_ENV, 'correlation_repository.json');
        if (correlationRepositoryConfig.storage) {
            const correlationRepositoryStoragePath = path.join(databaseBasePath, correlationRepositoryConfig.storage);
            process.env.process_engine__correlation_repository__storage = correlationRepositoryStoragePath;
        }
        const externalTaskRepositoryConfig = readConfigFile(process.env.NODE_ENV, 'external_task_repository.json');
        if (externalTaskRepositoryConfig.storage) {
            const externalTaskRepositoryStoragePath = path.join(databaseBasePath, externalTaskRepositoryConfig.storage);
            process.env.process_engine__external_task_repository__storage = externalTaskRepositoryStoragePath;
        }
        const flowNodeInstanceRepositoryConfig = readConfigFile(process.env.NODE_ENV, 'flow_node_instance_repository.json');
        if (flowNodeInstanceRepositoryConfig.storage) {
            const flowNodeRepositoryStoragePath = path.join(databaseBasePath, flowNodeInstanceRepositoryConfig.storage);
            process.env.process_engine__flow_node_instance_repository__storage = flowNodeRepositoryStoragePath;
        }
        const processModelRepositoryConfig = readConfigFile(process.env.NODE_ENV, 'process_model_repository.json');
        if (processModelRepositoryConfig.storage) {
            const processModelRepositoryStoragePath = path.join(databaseBasePath, processModelRepositoryConfig.storage);
            process.env.process_engine__process_model_repository__storage = processModelRepositoryStoragePath;
        }
    }
    exports.setDatabasePaths = setDatabasePaths;
    function getSqliteStoragePath(sqlitePath) {
        if (sqlitePath) {
            return sqlitePath;
        }
        const userDataFolderPath = getUserConfigFolder();
        const userDataProcessEngineFolderName = 'process_engine_runtime';
        const processEngineDatabaseFolderName = 'databases';
        const databaseBasePath = path.resolve(userDataFolderPath, userDataProcessEngineFolderName, processEngineDatabaseFolderName);
        return databaseBasePath;
    }
    exports.getSqliteStoragePath = getSqliteStoragePath;
    function getUserConfigFolder() {
        const userHomeDir = os.homedir();
        switch (process.platform) {
            case 'darwin':
                return path.join(userHomeDir, 'Library', 'Application Support');
            case 'win32':
                return path.join(userHomeDir, 'AppData', 'Roaming');
            default:
                return path.join(userHomeDir, '.config');
        }
    }
    exports.getUserConfigFolder = getUserConfigFolder;
    function readConfigFile(env, repositoryConfigFileName) {
        const configFilePath = path.resolve(process.env.CONFIG_PATH, env, 'process_engine', repositoryConfigFileName);
        const fileContent = fs.readFileSync(configFilePath, 'utf-8');
        const parsedFileContent = JSON.parse(fileContent);
        return parsedFileContent;
    }
    exports.readConfigFile = readConfigFile;
});
//# sourceMappingURL=environment.js.map